API Reference
====================================

DeltaTable
----------

.. automodule:: deltalake.table
    :members:

DeltaSchema
-----------

.. automodule:: deltalake.schema
    :members:

DataCatalog
-----------

.. automodule:: deltalake.data_catalog
    :members:

DeltaStorageHandler
-------------------

.. automodule:: deltalake.fs
    :members: